"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const widgets_1 = require("@phosphor/widgets");
const apputils_1 = require("@jupyterlab/apputils");
const jupyterlab_toastify_1 = require("jupyterlab_toastify");
var CommandIDs;
(function (CommandIDs) {
    CommandIDs.dashboard = 'Tools:dashboard';
})(CommandIDs = exports.CommandIDs || (exports.CommandIDs = {}));
;
class Sandbox extends widgets_1.Panel {
    constructor() {
        super();
        this._frame = new apputils_1.IFrame();
        this.addWidget(this._frame);
    }
    get iframeNode() {
        return this.node.querySelector('iframe');
    }
    // get sandboxAttr() {
    //   return Object.keys(this._sandBox || {}).join(' ');
    // }
    // get sandBox() {
    //   return this._sandBox
    // }
    // set sandBox(attrs: SandboxNS.TSandboxOptions) {
    //   this._sandBox = attrs
    //   this.iframeNode.setAttribute('sandbox', this.sandboxAttr)
    // }
    get url() {
        return this._frame.url;
    }
    set url(url) {
        this._frame.url = url;
    }
}
exports.Sandbox = Sandbox;
var INotificationID;
function iframeUrl(gKernel, url) {
    // Create a single widget
    let frame = new Sandbox();
    frame.id = 'dashboard-jupyterlab';
    frame.title.label = 'dashboard';
    frame.title.closable = true;
    frame.url = url;
    return frame;
}
function addMenuItem(app, mainMenu, palette, gKernel) {
    const category = 'Tools';
    const { commands } = app;
    commands.addCommand(CommandIDs.dashboard, {
        label: 'dashboard',
        execute: () => {
            console.log('dashboard');
            getDashBordUrl(gKernel, app);
            // let frame = iframeUrl(gKernel)
            // if (!frame.isAttached) {
            //   app.shell.addToMainArea(frame);
            // }
            // app.shell.activateById(frame.id);
        }
    });
    let menu = new widgets_1.Menu({ commands });
    menu.title.label = category;
    [
        CommandIDs.dashboard
    ].forEach(command => {
        palette.addItem({ command, category });
        menu.addItem({ command });
    });
    mainMenu.addMenu(menu, { rank: 100 });
}
exports.addMenuItem = addMenuItem;
function getDashBordUrl(gKernel, app) {
    const code = [
        '#!/usr/bin/env python3',
        '# -*- coding: utf-8 -*-',
        'import sys',
        'import logging',
        'import logging.config',
        'import subprocess',
        'import os',
        'logger = logging.getLogger(__name__)',
        'dashboard_ip = os.getenv("PAI_JUPYTER_DASHBOARD_IP")',
        'job_name = os.getenv("PAI_JOB_NAME")',
        'print(dashboard_ip)',
        'print(job_name)',
        'if(dashboard_ip):',
        '  print("get_ip_successfull")'
    ].join('\n');
    const future = gKernel.requestExecute({ code: code });
    let dashboardUrl = '';
    future.onIOPub = msg => {
        console.log(msg.content); // Print rich output data.
        if (msg.content.traceback) {
            jupyterlab_toastify_1.INotification.update({
                toastId: INotificationID,
                message: '获取dashboard失败',
                type: "error",
                autoClose: 5000,
                buttons: []
            });
        }
        else if (msg.content.name === 'stdout') {
            let printArr = msg.content.text.toString().split('\n');
            if (printArr.indexOf('get_ip_successfull') >= -1) {
                console.log('get dashboard successfull');
                dashboardUrl = `http://${printArr[0]}:9486/grafana/dashboard/db/tasklevelmetrics?var-job=${printArr[1]}&refresh=30s&orgId=1&kiosk`;
                console.log(dashboardUrl);
                let frame = iframeUrl(gKernel, dashboardUrl);
                if (!frame.isAttached) {
                    app.shell.addToMainArea(frame);
                }
                app.shell.activateById(frame.id);
            }
            else {
                jupyterlab_toastify_1.INotification.update({
                    toastId: INotificationID,
                    message: `获取dashboard失败`,
                    type: "error",
                    autoClose: 5000,
                    buttons: []
                });
            }
            console.log(printArr);
        }
    };
}
