"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const application_1 = require("@jupyterlab/application");
const filebrowser_1 = require("@jupyterlab/filebrowser");
const services_1 = require("@jupyterlab/services");
const mainmenu_1 = require("@jupyterlab/mainmenu");
const apputils_1 = require("@jupyterlab/apputils");
const jupyterlab_toastify_1 = require("jupyterlab_toastify");
const updateFromHDFS_1 = require("./updateFromHDFS");
const dashboard_1 = require("./dashboard");
require("../style/index.css");
var gKernel;
var localPath;
var hdfsPath;
/**
 * Initialization data for the jupyterlab_ext extension.
 */
const extension = {
    id: 'jupyterlab_ext',
    autoStart: true,
    requires: [filebrowser_1.IFileBrowserFactory, application_1.ILayoutRestorer, apputils_1.ICommandPalette, mainmenu_1.IMainMenu],
    activate: saveFiles
    // activate: (app: JupyterLab) => {
    //   console.log('JupyterLab extension jupyterlab_ext is activated!!');
    // }
};
function saveFiles(app, factory, restorer, palette, mainMenu) {
    console.log('JupyterLab extension jupyterlab_ext is activated!!');
    const browser = factory.defaultBrowser;
    creatKernel(factory, app, mainMenu, palette);
    addSaveCommand(app, factory.tracker, browser);
    // addMenuItem(app, mainMenu, palette, gKernel)
    // addUpdateItem(factory, gKernel)
}
function addSaveCommand(app, tracker, browser) {
    const { commands } = app;
    commands.addCommand('filebrowser:save-file', {
        execute: () => {
            const widget = tracker.currentWidget;
            if (!widget) {
                return;
            }
            const item = widget.selectedItems().next();
            if (!item) {
                return;
            }
            console.log(tracker.currentWidget);
            // Clipboard.copyToSystem(item.path);
            console.log(item, '=====');
            console.log(app);
            localPath = item.path;
            hdfsPath = localPathMapToHdfsPath(localPath);
            console.log(localPath, hdfsPath);
            // const isRoot = item.name === item.path
            executeCmd(localPath, hdfsPath);
        },
        isVisible: () => tracker.currentWidget &&
            tracker.currentWidget.selectedItems().next !== undefined,
        iconClass: 'jp-MaterialIcon jp-FileIcon',
        label: 'Save to workspace'
    });
    // matches all filebrowser items
    const selectorItem = '.jp-DirListing-item[data-isdir]';
    app.contextMenu.addItem({
        command: 'filebrowser:save-file',
        selector: selectorItem,
        rank: 14
    });
}
function localPathMapToHdfsPath(localPath) {
    let splitArr = localPath.split('/');
    splitArr.pop();
    return splitArr.join('/');
}
function creatKernel(factory, app, mainMenu, palette) {
    // Get a list of available kernels and connect to one.
    // Kernel.listRunning().then(kernelModels => {
    //   const kernel = Kernel.connectTo(kernelModels[0]);
    //   console.log(kernel.name);
    // });
    // Get info about the available kernels and start a new one.
    services_1.Kernel.getSpecs().then(kernelSpecs => {
        console.log('Default spec:', kernelSpecs.default);
        console.log('Available specs', Object.keys(kernelSpecs.kernelspecs));
        // use the default name
        let options = {
            name: kernelSpecs.default
        };
        services_1.Kernel.startNew(options).then(kernel => {
            gKernel = kernel;
            updateFromHDFS_1.addUpdateItem(factory, gKernel);
            dashboard_1.addMenuItem(app, mainMenu, palette, gKernel);
        });
    });
}
function executeCmd(localPath, hdfsPath) {
    const code = [
        '#!/usr/bin/env python3',
        '# -*- coding: utf-8 -*-',
        'import sys',
        'import logging',
        'import logging.config',
        'import subprocess',
        'import os',
        'logger = logging.getLogger(__name__)',
        'def execute_shell(shell_cmd, error_msg):',
        '  try:',
        '    subprocess.check_call( shell_cmd, shell=True )',
        '  except subprocess.CalledProcessError:',
        '    logger.error(error_msg)',
        '    sys.exit(1)',
        'def save_root_path(url):',
        '  arr = url.split("/")',
        '  arr.pop()',
        '  return "/".join(arr)',
        'def remove_hide_path(rootDir, root_path): ',
        '  list_dirs = os.walk(rootDir) ',
        '  for root, dirs, files in list_dirs: ',
        '    for d in dirs: ',
        '      if (d == ".ipynb_checkpoints"):',
        '        path = os.path.join(root, d)',
        '        pathArr = path.split("/")',
        '        pathArr = pathArr[2:]',
        '        resPath = "/".join(pathArr)',
        '        print(resPath)',
        '        execute_shell("hdfs dfs -rmr "+ root_path + "/" + resPath, "删除隐藏文件失败")',
        'url = os.getenv("PAI_CODE_DIR")',
        'if (url):',
        '  root_path = save_root_path(url)',
        `  execute_shell("hdfs dfs -mkdir -p " + root_path + "/${hdfsPath}", "创建目录失败")`,
        `  execute_shell("hdfs dfs -put -f /home/${localPath}  "+ root_path +"/${hdfsPath}", "保存失败")`,
        `  remove_hide_path("/home/${localPath}", root_path)`,
        '  print("save_files_successfull")',
        'else:',
        '  print("not_hdfs_url")'
    ].join('\n');
    var INotificationID;
    let tempArr = localPath.split('/');
    let filename = tempArr[tempArr.length - 1];
    console.log(filename);
    INotificationID = jupyterlab_toastify_1.INotification.inProgress("保存中...");
    const future = gKernel.requestExecute({ code: code });
    future.onIOPub = msg => {
        console.log(msg.content); // Print rich output data.
        if (msg.content.traceback) {
            jupyterlab_toastify_1.INotification.update({
                toastId: INotificationID,
                message: `${filename} 保存失败`,
                type: "error",
                autoClose: 5000,
                buttons: []
            });
        }
        else if (msg.content.name === 'stdout') {
            let printArr = msg.content.text.toString().split('\n');
            if (printArr.indexOf('not_hdfs_url') > -1) {
                jupyterlab_toastify_1.INotification.update({
                    toastId: INotificationID,
                    message: `您的任务没有挂载目录，不能保存文件`,
                    type: "warning",
                    autoClose: 5000,
                    buttons: []
                });
            }
            else if (printArr.indexOf('save_files_successfull') > -1) {
                jupyterlab_toastify_1.INotification.update({
                    toastId: INotificationID,
                    message: `${filename} 保存成功`,
                    type: "success",
                    autoClose: 5000,
                    buttons: []
                });
            }
            else {
                jupyterlab_toastify_1.INotification.update({
                    toastId: INotificationID,
                    message: `${filename} 保存失败`,
                    type: "error",
                    autoClose: 5000,
                    buttons: []
                });
            }
            console.log(printArr);
        }
    };
}
exports.default = extension;
