"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apputils_1 = require("@jupyterlab/apputils");
const widgets_1 = require("@phosphor/widgets");
const jupyterlab_toastify_1 = require("jupyterlab_toastify");
var INotificationID;
function addUpdateItem(factory, gKernel) {
    let fileBrowser;
    let enabledUpdateButton;
    fileBrowser = factory.defaultBrowser;
    enabledUpdateButton = new apputils_1.ToolbarButton({
        iconClassName: `jp-CopyIcon  jp-Icon jp-Icon-16`,
        onClick: () => {
            console.log('hhh');
            popDialog(factory, fileBrowser.model.path, gKernel, fileBrowser);
        },
        tooltip: 'Update From HDFS'
    });
    fileBrowser.toolbar.addItem('updateHDFS', enabledUpdateButton);
}
exports.addUpdateItem = addUpdateItem;
function popDialog(factory, currentPath, gKernel, fileBrowser) {
    // Dialog.prompt({
    //   prompt: 'pppppp',
    //   defaultValue: "erer"
    // })
    apputils_1.showDialog({
        title: '拉取hdfs数据到当前目录',
        body: new updateForm(),
        buttons: [apputils_1.Dialog.cancelButton({ label: '取消' }), apputils_1.Dialog.okButton({ label: '确认' })]
    }).then(result => {
        if (result.button.accept) {
            console.log(result.value);
            console.log(decodeURIComponent(result.value));
            result.value = decodeURIComponent(result.value);
            if (result.value.indexOf('hdfs') > -1) {
                executeCmd(currentPath, result.value, gKernel, fileBrowser);
            }
            else {
                jupyterlab_toastify_1.INotification.update({
                    toastId: INotificationID,
                    message: `请输入正确的hdfs地址`,
                    type: "error",
                    autoClose: 5000,
                    buttons: []
                });
            }
            console.log(currentPath, 'path');
        }
        console.log(result);
    });
}
class updateForm extends widgets_1.Widget {
    /**
     * Create a redirect form.
     */
    constructor() {
        super({ node: updateForm.createFormNode() });
    }
    static createFormNode() {
        const node = document.createElement('div');
        const label = document.createElement('label');
        const input = document.createElement('input');
        const text = document.createElement('span');
        const warning = document.createElement('div');
        const tip = document.createElement('div');
        node.className = 'jp-RedirectForm';
        warning.className = 'jp-RedirectForm-warning';
        text.textContent = '输入HDFS地址:';
        input.placeholder = 'hdfs://';
        tip.textContent = '注：该操作会覆盖相同名称的文件（文件夹）';
        label.appendChild(text);
        label.appendChild(input);
        node.appendChild(label);
        node.appendChild(tip);
        node.appendChild(warning);
        return node;
    }
    /**
     * Returns the input value.
     */
    getValue() {
        return encodeURIComponent(this.node.querySelector('input').value);
    }
}
function executeCmd(localPath, hdfsPath, gKernel, fileBrowser) {
    const code = [
        '#!/usr/bin/env python3',
        '# -*- coding: utf-8 -*-',
        'import sys',
        'import logging',
        'import logging.config',
        'import subprocess',
        'import os',
        'logger = logging.getLogger(__name__)',
        'def execute_shell(shell_cmd, error_msg):',
        '  try:',
        '    subprocess.check_call( shell_cmd, shell=True )',
        '  except subprocess.CalledProcessError:',
        '    logger.error(error_msg)',
        '    sys.exit(1)',
        `execute_shell("hdfs dfs -get -f " + " ${hdfsPath}" + " /home/${localPath}", "获取失败")`,
        'print("update_files_successfull")'
    ].join('\n');
    INotificationID = jupyterlab_toastify_1.INotification.inProgress("拉取文件中...");
    const future = gKernel.requestExecute({ code: code });
    future.onIOPub = msg => {
        console.log(msg.content); // Print rich output data.
        if (msg.content.traceback) {
            jupyterlab_toastify_1.INotification.update({
                toastId: INotificationID,
                message: `获取失败`,
                type: "error",
                autoClose: 5000,
                buttons: []
            });
        }
        else if (msg.content.name === 'stdout') {
            let printArr = msg.content.text.toString().split('\n');
            if (printArr.indexOf('update_files_successfull') > -1) {
                jupyterlab_toastify_1.INotification.update({
                    toastId: INotificationID,
                    message: `拉取成功`,
                    type: "success",
                    autoClose: 5000,
                    buttons: []
                });
            }
            else {
                jupyterlab_toastify_1.INotification.update({
                    toastId: INotificationID,
                    message: `获取失败`,
                    type: "error",
                    autoClose: 5000,
                    buttons: []
                });
            }
            console.log(printArr);
        }
        fileBrowser.model.refresh();
    };
}
